package io.swagger.test_swagger_java_client;

import io.swagger.client.*;
import io.swagger.client.auth.*;
import io.swagger.client.model.*;
import io.swagger.client.api.LoginApi;
import io.swagger.client.model.JwtDto;
import io.swagger.client.model.UserDto;
import io.swagger.client.ApiResponse;
import io.swagger.client.model.CustomerDto;
import io.swagger.client.api.CustomersApi;
import io.swagger.client.model.FleetDto;
import io.swagger.client.api.FleetsApi;
import io.swagger.client.model.PaginatedDto;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.fail;



public class App_FleetAPITest extends AbstractTest {
	
	public static CustomerDto createCustomer(CustomerDto customerDto, CustomersApi customerInstance) throws ApiException {

		Long id = null;
		
		if(customerDto == null) {
			customerDto = new CustomerDto();
			ApiResponse<String> customerResponse = customerInstance.createCustomerWithHttpInfo(customerDto);
			id = getIdFromResponse(customerResponse);
			customerDto.setId(id);
		} else {
			if (customerDto.getId() == null) {
				ApiResponse<String> customerResponse = customerInstance.createCustomerWithHttpInfo(customerDto);
				id = getIdFromResponse(customerResponse);
				customerDto.setId(id);
			} else {
				id = customerDto.getId();
			}
		}

		assertNotNull(id);
		
		customerDto = customerInstance.getCustomer(id, null);

		return customerDto;
	}
	
	public static FleetDto createFleet(FleetDto fleetDto, FleetsApi fleetInstance, CustomerDto customerDto) throws ApiException {

		Long id = null;
		
		if (customerDto != null) {
			if(fleetDto == null) {
				fleetDto = new FleetDto();
				fleetDto.setCustomer(customerDto.toId());
				ApiResponse<String> fleetResponse = fleetInstance.createFleetWithHttpInfo(fleetDto);
				id = getIdFromResponse(fleetResponse);
			} else {
				if (fleetDto.getId() == null) {				
					fleetDto.setCustomer(customerDto.toId());
					ApiResponse<String> fleetResponse = fleetInstance.createFleetWithHttpInfo(fleetDto);
					id = getIdFromResponse(fleetResponse);
				} else {
					id = fleetDto.getId();
				}
			}
	
			assertNotNull(id);
			
			fleetDto = fleetInstance.getFleet(id, null);
		}
		
		return fleetDto;
	}
	

    public static void main(String[] args) throws ApiException {

      long id1=0, id_fleet=0; 	

      // Say Hello
      System.out.println("Hello world");
        
      String baseApiUrl = "https://wmcintegration.wanesy.com/";
  	  int connectTimeout = 60000;
  	  
  	  // Create an ApiClient per thread
  	  ApiClient defaultClient = Configuration.getDefaultApiClient();
  	  
  	  defaultClient.setBasePath(baseApiUrl); 	  
  	  defaultClient.setConnectTimeout(connectTimeout);
  	  defaultClient.setDebugging(true);
  	
  	  // login 
  	  
  	  LoginApi loginApi = new LoginApi(defaultClient);
  	  
  	  UserDto body = new UserDto ();
  	  body.setLogin("tda");
  	  body.setPassword("kerlinkkerlink");
  	  
  	  System.out.println("Login Post");
  	
  	  JwtDto jwt = loginApi.login(body);
	
  	  defaultClient.setApiKey("Bearer " + jwt.getToken());
  	  Configuration.setDefaultApiClient(defaultClient);
  	 
	 //createCustomer
  	  
  	 CustomersApi customerInstance = new CustomersApi();
	 CustomerDto customerDto = new CustomerDto();
	 	
  	 try {  
		 	  		
  		 	customerDto.setName("My company");  		 	
  		 	customerDto = createCustomer(customerDto, customerInstance);
  		 	id1 = customerDto.getId();
		  	System.out.println("CustomerId="+id1);	
		  	
	  } catch (ApiException e) {
	  	    System.err.println("Exception when calling CustomersApi#createCustomer");
	  	    e.printStackTrace();   
	  }
  	 
	  // getCustomers - a single instance
	  
  	  String sort = ""; // Sort value
	  String pageSize = ""; // Page size value
	  String search = "{\"operand\": \"name\", \"operation\": \"EQ\",	\"values\": [\"My company\"]}"; // Search condition
	  String fields = ""; // List of fields to display
	  String page = ""; // Page number
	  try {
		  PaginatedDto<CustomerDto> paginatedDto =  customerInstance.getCustomers(fields, page, pageSize, search, sort);
	  	  assertEquals(Integer.valueOf(1), paginatedDto.getCount());
	  	  
	  } catch (ApiException e) {
	  	    System.err.println("Exception when calling CustomersApi#applicationCustomersGet");
	  	    e.printStackTrace();
	  }
  	    
	  
	  // createFleet
	  FleetsApi fleetInstance = new FleetsApi();
	  FleetDto fleetDto = new FleetDto();
	  
	  try { 		  
		  
		  fleetDto.setName("My fleet");
		  fleetDto = createFleet(fleetDto, fleetInstance, customerDto);
		  id_fleet = fleetDto.getId();
		  System.out.println("FleetId="+id_fleet);	
	  }
	  catch (ApiException e) {
	  	    System.err.println("Exception when calling FleetsApi#createFleet");
	  	    e.printStackTrace();   
	  }
	  
	  // getFleets
	  
	  sort = ""; // Sort value
	  pageSize = ""; // Page size value
	  search = "{\"operand\": \"name\", \"operation\": \"EQ\",	\"values\": [\"My fleet\"]}"; // Search condition
	  fields = ""; // List of fields to display
	  page = ""; // Page number
	  try {
		  PaginatedDto<FleetDto> paginatedDto =  fleetInstance.getFleets(fields, page, pageSize, search, sort);
	  	  assertEquals(Integer.valueOf(1), paginatedDto.getCount());
	  	  
	  } catch (ApiException e) {
	  	    System.err.println("Exception when calling FleetsApi#getFleets");
	  	    e.printStackTrace();
	  }
  	    
	  // getFleet
	  fleetDto = fleetInstance.getFleet(id_fleet, null);
	  System.out.println("The fleet Id="+id_fleet+" has name \""+fleetDto.getName()+"\"");	
	  
	  // deleteFleet
	  fleetInstance.deleteFleet(id_fleet);
	  System.out.println("The fleet Id="+id_fleet+" has been deleted=");
	  
	  // deleteCustomer
	  customerInstance.deleteCustomer(id1);
	  System.out.println("The customer Id="+id1+" has been deleted");
  }
}
    
    